@@ -14,12 +14,10 @@
 #
 
 import copy
-import fixtures
 import mock
 import os
 import testtools
 
-from osc_lib import shell
 from osc_lib.tests import utils
 
 
@@ -117,68 +115,12 @@ global_options = {
 }
 
 
-def opt2attr(opt):
-    if opt.startswith('--os-'):
-        attr = opt[5:]
-    elif opt.startswith('--'):
-        attr = opt[2:]
-    else:
-        attr = opt
-    return attr.lower().replace('-', '_')
-
-
-def opt2env(opt):
-    return opt[2:].upper().replace('-', '_')
-
-
-def make_shell():
-    """Create a new command shell and mock out some bits."""
-    _shell = shell.OpenStackShell()
-    _shell.command_manager = mock.Mock()
-    _shell.cloud = mock.Mock()
-
-    return _shell
-
-
-def fake_execute(shell, cmd):
-    """Pretend to execute shell commands."""
-    return shell.run(cmd.split())
-
-
-class EnvFixture(fixtures.Fixture):
-    """Environment Fixture.
-
-    This fixture replaces os.environ with provided env or an empty env.
-    """
-
-    def __init__(self, env=None):
-        self.new_env = env or {}
-
-    def _setUp(self):
-        self.orig_env, os.environ = os.environ, self.new_env
-        self.addCleanup(self.revert)
-
-    def revert(self):
-        os.environ = self.orig_env
-
-
-class TestShell(utils.TestCase):
-
-    def setUp(self):
-        super(TestShell, self).setUp()
-        patch = "osc_lib.shell.OpenStackShell.run_subcommand"
-        self.cmd_patch = mock.patch(patch)
-        self.cmd_save = self.cmd_patch.start()
-        self.addCleanup(self.cmd_patch.stop)
-        self.app = mock.Mock("Test Shell")
-
-
-class TestShellHelp(TestShell):
+class TestShellHelp(utils.TestShell):
     """Test the deferred help flag"""
 
     def setUp(self):
         super(TestShellHelp, self).setUp()
-        self.useFixture(EnvFixture())
+        self.useFixture(utils.EnvFixture())
 
     @testtools.skip("skip until bug 1444983 is resolved")
     def test_help_options(self):
@@ -186,12 +128,9 @@ class TestShellHelp(TestShell):
         kwargs = {
             "deferred_help": True,
         }
-        with mock.patch(
-                "osc_lib.shell.OpenStackShell.initialize_app",
-                self.app,
-        ):
-            _shell, _cmd = make_shell(), flag
-            fake_execute(_shell, _cmd)
+        with mock.patch(self.app_patch + ".initialize_app", self.app):
+            _shell, _cmd = utils.make_shell(), flag
+            utils.fake_execute(_shell, _cmd)
 
             self.assertEqual(
                 kwargs["deferred_help"],
@@ -199,7 +138,7 @@ class TestShellHelp(TestShell):
             )
 
 
-class TestShellOptions(TestShell):
+class TestShellOptions(utils.TestShell):
     """Test the option handling by argparse and os_client_config
 
     This covers getting the CLI options through the initial processing
@@ -208,119 +147,12 @@ class TestShellOptions(TestShell):
 
     def setUp(self):
         super(TestShellOptions, self).setUp()
-        self.useFixture(EnvFixture())
+        self.useFixture(utils.EnvFixture())
 
-    def _assert_initialize_app_arg(self, cmd_options, default_args):
-        """Check the args passed to initialize_app()
-
-        The argv argument to initialize_app() is the remainder from parsing
-        global options declared in both cliff.app and
-        osc_lib.OpenStackShell build_option_parser().  Any global
-        options passed on the command line should not be in argv but in
-        _shell.options.
-        """
-
-        with mock.patch(
-                "osc_lib.shell.OpenStackShell.initialize_app",
-                self.app,
-        ):
-            _shell, _cmd = make_shell(), cmd_options + " module list"
-            fake_execute(_shell, _cmd)
-
-            self.app.assert_called_with(["module", "list"])
-            for k in default_args.keys():
-                self.assertEqual(
-                    default_args[k],
-                    vars(_shell.options)[k],
-                    "%s does not match" % k,
-                )
-
-    def _assert_cloud_config_arg(self, cmd_options, default_args):
-        """Check the args passed to cloud_config.get_one_cloud()
-
-        The argparse argument to get_one_cloud() is an argparse.Namespace
-        object that contains all of the options processed to this point in
-        initialize_app().
-        """
-
-        cloud = mock.Mock(name="cloudy")
-        cloud.config = {}
-        self.occ_get_one = mock.Mock(return_value=cloud)
-        with mock.patch(
-                "os_client_config.config.OpenStackConfig.get_one_cloud",
-                self.occ_get_one,
-        ):
-            _shell, _cmd = make_shell(), cmd_options + " module list"
-            fake_execute(_shell, _cmd)
-
-            self.app.assert_called_with(["module", "list"])
-            opts = self.occ_get_one.call_args[1]['argparse']
-            for k in default_args.keys():
-                self.assertEqual(
-                    default_args[k],
-                    vars(opts)[k],
-                    "%s does not match" % k,
-                )
-
-    def _test_options_init_app(self, test_opts):
-        """Test options on the command line"""
-        for opt in test_opts.keys():
-            if not test_opts[opt][1]:
-                continue
-            key = opt2attr(opt)
-            if isinstance(test_opts[opt][0], str):
-                cmd = opt + " " + test_opts[opt][0]
-            else:
-                cmd = opt
-            kwargs = {
-                key: test_opts[opt][0],
-            }
-            self._assert_initialize_app_arg(cmd, kwargs)
-
-    def _test_env_init_app(self, test_opts):
-        """Test options in the environment"""
-        for opt in test_opts.keys():
-            if not test_opts[opt][2]:
-                continue
-            key = opt2attr(opt)
-            kwargs = {
-                key: test_opts[opt][0],
-            }
-            env = {
-                opt2env(opt): test_opts[opt][0],
-            }
-            os.environ = env.copy()
-            self._assert_initialize_app_arg("", kwargs)
-
-    def _test_options_get_one_cloud(self, test_opts):
-        """Test options sent "to os_client_config"""
-        for opt in test_opts.keys():
-            if not test_opts[opt][1]:
-                continue
-            key = opt2attr(opt)
-            if isinstance(test_opts[opt][0], str):
-                cmd = opt + " " + test_opts[opt][0]
-            else:
-                cmd = opt
-            kwargs = {
-                key: test_opts[opt][0],
-            }
-            self._assert_cloud_config_arg(cmd, kwargs)
-
-    def _test_env_get_one_cloud(self, test_opts):
-        """Test environment options sent "to os_client_config"""
-        for opt in test_opts.keys():
-            if not test_opts[opt][2]:
-                continue
-            key = opt2attr(opt)
-            kwargs = {
-                key: test_opts[opt][0],
-            }
-            env = {
-                opt2env(opt): test_opts[opt][0],
-            }
-            os.environ = env.copy()
-            self._assert_cloud_config_arg("", kwargs)
+    def test_empty_auth(self):
+        os.environ = {}
+        self._assert_initialize_app_arg("", {})
+        self._assert_cloud_config_arg("", {})
 
     def test_no_options(self):
         os.environ = {}
@@ -336,7 +168,7 @@ class TestShellOptions(TestShell):
         self._test_env_get_one_cloud(global_options)
 
 
-class TestShellCli(TestShell):
+class TestShellCli(utils.TestShell):
     """Test handling of specific global options
 
     _shell.options is the parsed command line from argparse
@@ -347,14 +179,23 @@ class TestShellCli(TestShell):
     def setUp(self):
         super(TestShellCli, self).setUp()
         env = {}
-        self.useFixture(EnvFixture(env.copy()))
+        self.useFixture(utils.EnvFixture(env.copy()))
+
+    def test_shell_args_no_options(self):
+        _shell = utils.make_shell()
+        with mock.patch(
+                "osc_lib.shell.OpenStackShell.initialize_app",
+                self.app,
+        ):
+            utils.fake_execute(_shell, "list user")
+            self.app.assert_called_with(["list", "user"])
 
     def test_shell_args_tls_options(self):
         """Test the TLS verify and CA cert file options"""
-        _shell = make_shell()
+        _shell = utils.make_shell()
 
         # Default
-        fake_execute(_shell, "module list")
+        utils.fake_execute(_shell, "module list")
         self.assertIsNone(_shell.options.verify)
         self.assertIsNone(_shell.options.insecure)
         self.assertIsNone(_shell.options.cacert)
@@ -362,7 +203,7 @@ class TestShellCli(TestShell):
         self.assertIsNone(_shell.client_manager.cacert)
 
         # --verify
-        fake_execute(_shell, "--verify module list")
+        utils.fake_execute(_shell, "--verify module list")
         self.assertTrue(_shell.options.verify)
         self.assertIsNone(_shell.options.insecure)
         self.assertIsNone(_shell.options.cacert)
@@ -370,7 +211,7 @@ class TestShellCli(TestShell):
         self.assertIsNone(_shell.client_manager.cacert)
 
         # --insecure
-        fake_execute(_shell, "--insecure module list")
+        utils.fake_execute(_shell, "--insecure module list")
         self.assertIsNone(_shell.options.verify)
         self.assertTrue(_shell.options.insecure)
         self.assertIsNone(_shell.options.cacert)
@@ -378,7 +219,7 @@ class TestShellCli(TestShell):
         self.assertIsNone(_shell.client_manager.cacert)
 
         # --os-cacert
-        fake_execute(_shell, "--os-cacert foo module list")
+        utils.fake_execute(_shell, "--os-cacert foo module list")
         self.assertIsNone(_shell.options.verify)
         self.assertIsNone(_shell.options.insecure)
         self.assertEqual('foo', _shell.options.cacert)
@@ -386,7 +227,7 @@ class TestShellCli(TestShell):
         self.assertEqual('foo', _shell.client_manager.cacert)
 
         # --os-cacert and --verify
-        fake_execute(_shell, "--os-cacert foo --verify module list")
+        utils.fake_execute(_shell, "--os-cacert foo --verify module list")
         self.assertTrue(_shell.options.verify)
         self.assertIsNone(_shell.options.insecure)
         self.assertEqual('foo', _shell.options.cacert)
@@ -398,7 +239,7 @@ class TestShellCli(TestShell):
         #                in this combination --insecure now overrides any
         #                --os-cacert setting, where before --insecure
         #                was ignored if --os-cacert was set.
-        fake_execute(_shell, "--os-cacert foo --insecure module list")
+        utils.fake_execute(_shell, "--os-cacert foo --insecure module list")
         self.assertIsNone(_shell.options.verify)
         self.assertTrue(_shell.options.insecure)
         self.assertEqual('foo', _shell.options.cacert)
@@ -407,28 +248,31 @@ class TestShellCli(TestShell):
 
     def test_shell_args_cert_options(self):
         """Test client cert options"""
-        _shell = make_shell()
+        _shell = utils.make_shell()
 
         # Default
-        fake_execute(_shell, "module list")
+        utils.fake_execute(_shell, "module list")
         self.assertEqual('', _shell.options.cert)
         self.assertEqual('', _shell.options.key)
         self.assertIsNone(_shell.client_manager.cert)
 
         # --os-cert
-        fake_execute(_shell, "--os-cert mycert module list")
+        utils.fake_execute(_shell, "--os-cert mycert module list")
         self.assertEqual('mycert', _shell.options.cert)
         self.assertEqual('', _shell.options.key)
         self.assertEqual('mycert', _shell.client_manager.cert)
 
         # --os-key
-        fake_execute(_shell, "--os-key mickey module list")
+        utils.fake_execute(_shell, "--os-key mickey module list")
         self.assertEqual('', _shell.options.cert)
         self.assertEqual('mickey', _shell.options.key)
         self.assertIsNone(_shell.client_manager.cert)
 
         # --os-cert and --os-key
-        fake_execute(_shell, "--os-cert mycert --os-key mickey module list")
+        utils.fake_execute(
+            _shell,
+            "--os-cert mycert --os-key mickey module list"
+        )
         self.assertEqual('mycert', _shell.options.cert)
         self.assertEqual('mickey', _shell.options.key)
         self.assertEqual(('mycert', 'mickey'), _shell.client_manager.cert)
@@ -437,9 +281,9 @@ class TestShellCli(TestShell):
     def test_shell_args_cloud_no_vendor(self, config_mock):
         """Test cloud config options without the vendor file"""
         config_mock.return_value = ('file.yaml', copy.deepcopy(CLOUD_1))
-        _shell = make_shell()
+        _shell = utils.make_shell()
 
-        fake_execute(
+        utils.fake_execute(
             _shell,
             "--os-cloud scc module list",
         )
@@ -488,9 +332,9 @@ class TestShellCli(TestShell):
         """Test cloud config options with the vendor file"""
         config_mock.return_value = ('file.yaml', copy.deepcopy(CLOUD_2))
         public_mock.return_value = ('file.yaml', copy.deepcopy(PUBLIC_1))
-        _shell = make_shell()
+        _shell = utils.make_shell()
 
-        fake_execute(
+        utils.fake_execute(
             _shell,
             "--os-cloud megacloud module list",
         )
@@ -536,10 +380,10 @@ class TestShellCli(TestShell):
     def test_shell_args_precedence(self, config_mock, vendor_mock):
         config_mock.return_value = ('file.yaml', copy.deepcopy(CLOUD_2))
         vendor_mock.return_value = ('file.yaml', copy.deepcopy(PUBLIC_1))
-        _shell = make_shell()
+        _shell = utils.make_shell()
 
         # Test command option overriding config file value
-        fake_execute(
+        utils.fake_execute(
             _shell,
             "--os-cloud megacloud --os-region-name krikkit module list",
         )
@@ -577,7 +421,7 @@ class TestShellCli(TestShell):
         )
 
 
-class TestShellCliPrecedence(TestShell):
+class TestShellCliPrecedence(utils.TestShell):
     """Test option precedencr order"""
 
     def setUp(self):
@@ -586,7 +430,7 @@ class TestShellCliPrecedence(TestShell):
             'OS_CLOUD': 'megacloud',
             'OS_REGION_NAME': 'occ-env',
         }
-        self.useFixture(EnvFixture(env.copy()))
+        self.useFixture(utils.EnvFixture(env.copy()))
 
     @mock.patch("os_client_config.config.OpenStackConfig._load_vendor_file")
     @mock.patch("os_client_config.config.OpenStackConfig._load_config_file")
@@ -594,10 +438,10 @@ class TestShellCliPrecedence(TestShell):
         """Test environment overriding occ"""
         config_mock.return_value = ('file.yaml', copy.deepcopy(CLOUD_2))
         vendor_mock.return_value = ('file.yaml', copy.deepcopy(PUBLIC_1))
-        _shell = make_shell()
+        _shell = utils.make_shell()
 
         # Test env var
-        fake_execute(
+        utils.fake_execute(
             _shell,
             "module list",
         )
@@ -642,10 +486,10 @@ class TestShellCliPrecedence(TestShell):
         """Test command line overriding environment and occ"""
         config_mock.return_value = ('file.yaml', copy.deepcopy(CLOUD_2))
         vendor_mock.return_value = ('file.yaml', copy.deepcopy(PUBLIC_1))
-        _shell = make_shell()
+        _shell = utils.make_shell()
 
         # Test command option overriding config file value
-        fake_execute(
+        utils.fake_execute(
             _shell,
             "--os-region-name krikkit list user",
         )
@@ -690,10 +534,10 @@ class TestShellCliPrecedence(TestShell):
         """Test command line overriding environment and occ"""
         config_mock.return_value = ('file.yaml', copy.deepcopy(CLOUD_1))
         vendor_mock.return_value = ('file.yaml', copy.deepcopy(PUBLIC_1))
-        _shell = make_shell()
+        _shell = utils.make_shell()
 
         # Test command option overriding config file value
-        fake_execute(
+        utils.fake_execute(
             _shell,
             "--os-cloud scc --os-region-name krikkit list user",
         )
